@@ -122,17 +122,16 @@ ps_begin_path(double width)	// Q: what's with this width=-1 condition??
 		fprintf(_grPS, "] %d d\n", int(_dash.size()));
 		break;
 	case svg:
-		fprintf(stderr, "%s:%d:gr_begin_path() is ignoring line color on SVG output\n", __FILE__,__LINE__);
-		fprintf(stderr, "%s:%d:gr_begin_path() is ignoring line_cap   on SVG output\n", __FILE__,__LINE__);
-		fprintf(stderr, "%s:%d:gr_begin_path() is ignoring line_join  on SVG output\n", __FILE__,__LINE__);
-		if (width != -1) {
-			fprintf(_grSVG, "<g>\n<path style=\"stroke:#000000; stroke-width:%.3f; fill:none\"\nd=\"\n", width);
-		} else {
-			fprintf(_grSVG, "<g>\n<path style=\"stroke:#000000; stroke-width:%.3f; fill:none\"\nd=\"\n", _griState.linewidth_line());
-		}
-		if (_dash.size() > 0) {
+		fprintf(_grSVG, "<g>\n<path style=\"stroke:#%02x%02x%02x; stroke-width:%.3f; fill:none;stroke-opacity:%f;stroke-linejoin:%s;stroke-linecap:%s\"\nd=\"\n",
+			int(255.0*_griState.color_line().getR()),
+			int(255.0*_griState.color_line().getG()),
+			int(255.0*_griState.color_line().getB()),
+			_griState.linewidth_line(),
+			1.0 - _griState.color_line().getT(),
+			_griState.line_join() == 0 ? "sharp" : (_griState.line_join() == 1 ? "round" : "bevel"),
+			_griState.line_cap()  == 0 ? "butt"  : (_griState.line_cap()  == 1 ? "round" : "square"));
+		if (_dash.size() > 0)
 			fprintf(stderr, "%s:%d:gr_begin_path() is ignoring dash type for SVG output\n", __FILE__,__LINE__);			
-		}
 		break;
 	}
 }
@@ -151,6 +150,7 @@ void GriPath::fill(units the_units, bool closepath)
 
 void GriPath::stroke_or_fill(char s_or_f, units the_units, double width, bool closepath)
 {
+	double page_height_pt = gr_page_height_pt();
 	if (depth < 1)
 		return;
 	const unsigned int max_length = GR_POINTS_IN_PS_PATH - 1;
@@ -161,9 +161,9 @@ void GriPath::stroke_or_fill(char s_or_f, units the_units, double width, bool cl
 			break;
 	if (i == depth)
 		return;
-	if (_output_file_type != postscript) {
-		fprintf(stderr, "%s:%d:stroke_or_file() is broken on non-postscript file output\n", __FILE__,__LINE__);
-	}
+//	if (_output_file_type != postscript) {
+//		fprintf(stderr, "%s:%d:stroke_or_file() is broken on non-postscript file output\n", __FILE__,__LINE__);
+//	}
 	// must be some data.  Process island by island
 	double        *xc = new double[depth];	if (!xc) OUT_OF_MEMORY;
 	double        *yc = new double[depth];	if (!yc) OUT_OF_MEMORY;
@@ -243,7 +243,7 @@ void GriPath::stroke_or_fill(char s_or_f, units the_units, double width, bool cl
 					 || xc[i] > OFFPAGE_RIGHT
 					 || yc[i] < OFFPAGE_BOTTOM
 					 || yc[i] > OFFPAGE_TOP)) {
-					warning("`draw curve' detected a point which is offpage.");
+					warning("Gri drew a point that is offpage.");
 				}
 				switch (ac[i]) {
 				case GriPath::moveto:		// moveto (skip multiple)
@@ -256,7 +256,7 @@ void GriPath::stroke_or_fill(char s_or_f, units the_units, double width, bool cl
 						fprintf(_grPS, "%.2f %.2f m\n", xc[i] * PT_PER_CM, yc[i] * PT_PER_CM);
 						break;
 					case svg:
-						fprintf(_grSVG, "M%.2f %.2f\n", xc[i] * PT_PER_CM, yc[i] * PT_PER_CM);
+						fprintf(_grSVG, "M%.2f %.2f\n", xc[i] * PT_PER_CM, page_height_pt - yc[i] * PT_PER_CM);
 						break;
 					case gif:
 						break;
@@ -273,7 +273,7 @@ void GriPath::stroke_or_fill(char s_or_f, units the_units, double width, bool cl
 						fprintf(_grPS, "%.2f %.2f l\n", xc[i] * PT_PER_CM, yc[i] * PT_PER_CM);
 						break;
 					case svg:
-						fprintf(_grSVG, "L%.2f %.2f\n", xc[i] * PT_PER_CM, yc[i] * PT_PER_CM);
+						fprintf(_grSVG, "L%.2f %.2f\n", xc[i] * PT_PER_CM, gr_page_height_pt() - yc[i] * PT_PER_CM);
 						break;
 					case gif:
 						break;
@@ -294,7 +294,7 @@ void GriPath::stroke_or_fill(char s_or_f, units the_units, double width, bool cl
 				fprintf(_grPS, "%% END GriPath stroke/fill\n");
 				break;
 			case svg:
-				fprintf(stderr, "%s:%d:GriPath.cc is ignoring the _type_ of path (filled/stroked, etc)\n", __FILE__,__LINE__);
+				fprintf(stderr, "%s:%d:GriPath.cc SVG is not being told the _type_ of path (filled/stroked, etc)\n", __FILE__,__LINE__);
 				fprintf(_grSVG, "\"/>\n</g>\n");
 				break;
 			case gif:
