@@ -1,6 +1,6 @@
+//#define DEBUG_LABELS 1
 #include <string>
 #include <string.h>
-
 #if !defined(IS_MINGW32)
 #include <strings.h>
 #else
@@ -122,11 +122,10 @@ gr_drawxyaxes(double xl, double xinc, double xr, double yb, double yinc, double
 void
 gr_drawxaxis(double y, double xl, double xinc, double xr, gr_axis_properties side)
 {
-#if 1				// 2.9.x
 	bool user_gave_labels = (_x_labels.size() != 0);
-#if 0				// debugging
+#ifdef DEBUG_LABELS
 	if (user_gave_labels) {
-		printf("DEBUG: x axis should have labels [");
+		printf("DEBUG: %s:%d x axis should have labels [", __FILE__,__LINE__);
 		for (unsigned int i = 0; i < _x_labels.size(); i++)
 			printf("'%s' ", _x_labels[i].c_str());
 		printf("] at positions [");
@@ -135,12 +134,14 @@ gr_drawxaxis(double y, double xl, double xinc, double xr, gr_axis_properties sid
 		printf("]\n");
 	}
 #endif	
-#endif // 2.9.x
 	GriString label;
 	std::string slabel;
 	extern char     _xtype_map;
 	double          CapHeight = gr_currentCapHeight_cm();
 	double          angle = 0.0;	// angle of axis tics, labels, etc
+#ifdef DEBUG_LABELS
+	printf("DEBUG: %s:%d at top of gr_drawxaxis(), angle is %f\n", __FILE__, __LINE__, angle);
+#endif
 	bool            increasing = ((xr > xl) ? true : false);
 	double          tic, tic_sml;	// length of tic marks
 	double          xcm, ycm;	// tmp
@@ -204,7 +205,7 @@ gr_drawxaxis(double y, double xl, double xinc, double xr, gr_axis_properties sid
 			switch (_grTransform_x) {
 			case gr_axis_LINEAR:
 			case gr_axis_LOG:
-				angle = atan2(1.0, 0.0);
+				angle = atan2(1.0, 0.0); // angle for tics
 				break;
 			default:
 				gr_Error("unknown axis type (internal error)");
@@ -274,8 +275,10 @@ gr_drawxaxis(double y, double xl, double xinc, double xr, gr_axis_properties sid
 					} else {
 						*_grTempString = '\0';
 					}
-					// Text is rotated
-					angle -= 90.0 / DEG_PER_RAD;
+					angle = 0;
+#ifdef DEBUG_LABELS
+					printf("DEBUG: %s:%d after the loop, angle is %f\n", __FILE__, __LINE__, angle);
+#endif
 					if (!user_gave_labels) {
 						slabel.assign(_grTempString);
 						fix_negative_zero(slabel);
@@ -294,14 +297,23 @@ gr_drawxaxis(double y, double xl, double xinc, double xr, gr_axis_properties sid
 			present = next;
 		}
 		if (user_gave_labels) {
+			angle = 0;
 			for (unsigned int i = 0; i < _x_labels.size(); i++) {
-				label.fromSTR(_x_labels[i].c_str()); // BUG: should interpolate into this string
-				gr_usertocm(_x_label_positions[i], y, &xcm, &ycm);
-				//printf("'%s' xcm=%f   ycm=%f  offset=%f  y=%f\n", _x_labels[i].c_str(),xcm,ycm,offset,y);
-				label.draw(xcm - offset * sin(angle),
-					   ycm + offset * cos(angle),
-					   TEXT_CENTERED,
-					   DEG_PER_RAD * angle);
+				if (BETWEEN(xl, xr, _x_label_positions[i])) {
+					label.fromSTR(_x_labels[i].c_str()); // BUG: should interpolate into this string
+					gr_usertocm(_x_label_positions[i], y, &xcm, &ycm);
+#ifdef DEBUG_LABELS
+					printf("DEBUG: %s:%d drawing %d-th label '%s' at x=%f angle=%f\n",__FILE__,__LINE__,i,_x_labels[i].c_str(),_x_label_positions[i],angle);
+#endif
+					label.draw(xcm - offset * sin(angle),
+						   ycm + offset * cos(angle),
+						   TEXT_CENTERED,
+						   DEG_PER_RAD * angle);
+				} else {
+#ifdef DEBUG_LABELS
+					//printf("DEBUG: %s:%d SKIPPING %d-th label '%s' since x=%f\n",__FILE__,__LINE__,i,_x_labels[i].c_str(),_x_label_positions[i]);
+#endif
+				}
 			}
 		}
 		// Finish by drawing to end of axis (in case there was no tic there).
@@ -326,11 +338,8 @@ gr_drawxaxis(double y, double xl, double xinc, double xr, gr_axis_properties sid
 				gr_cmtouser(xcm, ycm+tic, &xuser, &yuser);
 				axis_path.push_back(xuser, yuser, 'l');
 				gr_cmtouser(xcm, ycm+offset, &xuser, &yuser);
-				tmp = next_log
-					- decade_between_labels * floor(next_log / decade_between_labels);
-				if (gr_currentfontsize_pt() > SMALLFONTSIZE
-				    && -0.01 < tmp / xinc && tmp / xinc < 0.01
-				    && strlen(_grNumFormat_x)) {
+				tmp = next_log - decade_between_labels * floor(next_log / decade_between_labels);
+				if (!user_gave_labels && gr_currentfontsize_pt() > SMALLFONTSIZE && -0.01 < tmp / xinc && tmp / xinc < 0.01 && strlen(_grNumFormat_x)) {
 					// Draw "1" as a special case
 					if (0.99 < next && next < 1.01)
 						sprintf(_grTempString, "1");
@@ -349,6 +358,23 @@ gr_drawxaxis(double y, double xl, double xinc, double xr, gr_axis_properties sid
 			axis_path.push_back(next, y, 'm');
 			present = next;
 		}
+		if (user_gave_labels) {
+			angle = 0;
+			for (unsigned int i = 0; i < _x_labels.size(); i++) {
+				if (BETWEEN(xl, xr, _x_label_positions[i])) {
+					label.fromSTR(_x_labels[i].c_str()); // BUG: should interpolate into this string
+					gr_usertocm(_x_label_positions[i], y, &xcm, &ycm);
+#ifdef DEBUG_LABELS
+					printf("DEBUG: %s:%d drawing %d-th label '%s' at x=%f angle=%f\n",__FILE__,__LINE__,i,_x_labels[i].c_str(),_x_label_positions[i],angle);
+#endif
+					label.draw(xcm - offset * sin(angle), ycm + offset * cos(angle), TEXT_CENTERED, DEG_PER_RAD * angle);
+				} else {
+#ifdef DEBUG_LABELS
+					//printf("DEBUG: %s:%d SKIPPING %d-th label '%s' since x=%f\n",__FILE__,__LINE__,i,_x_labels[i].c_str(),_x_label_positions[i]);
+#endif
+				}
+			}
+		}
 		// Finish by drawing to end of axis (in case there was no tic there).
 		axis_path.push_back(final, y, 'l');
 		axis_path.stroke(units_user, _griState.linewidth_axis());
@@ -556,11 +582,11 @@ gr_drawyaxis(double x, double yb, double yinc, double yt, gr_axis_properties sid
 		}
 #if 1				// 2.9.x
 		if (user_gave_labels) {
-			//printf("labels...\n");
+		  //printf("labels...\n");
 			for (unsigned int i = 0; i < _y_labels.size(); i++) {
 				label.fromSTR(_y_labels[i].c_str()); // BUG: should interpolate into this string
 				gr_usertocm(x, _y_label_positions[i], &xcm, &ycm);
-				labelx_cm = xcm;
+				labelx_cm = xcm + offset * cos(angle);
 				labely_cm = ycm + offset * sin(angle) - 0.5 * CapHeight;
 				//printf("%f %f %f %f\n", ycm, offset*sin(angle),CapHeight, labely_cm);
 				if (side == gr_axis_LEFT)
@@ -596,7 +622,7 @@ gr_drawyaxis(double x, double yb, double yinc, double yt, gr_axis_properties sid
 				axis_path.push_back(xuser, yuser, 'l');
 				gr_cmtouser(xcm2 + tic, ycm2 - 0.5 * FACTOR * CapHeight, &xuser, &yuser);
 				tmp = next_log - decade_between_labels * floor(next_log / decade_between_labels);
-				if (gr_currentfontsize_pt() > SMALLFONTSIZE
+				if (!user_gave_labels && gr_currentfontsize_pt() > SMALLFONTSIZE
 				    && -0.01 < tmp / yinc && tmp / yinc< 0.01
 				    && strlen(_grNumFormat_y)) {
 					// Draw "1" as a special case
@@ -626,6 +652,29 @@ gr_drawyaxis(double x, double yb, double yinc, double yt, gr_axis_properties sid
 			axis_path.push_back(x, next, 'l');
 			present = next;
 		}
+		if (user_gave_labels) {
+			angle = 0;
+			for (unsigned int i = 0; i < _y_labels.size(); i++) {
+				if (BETWEEN(yb, yt, _y_label_positions[i])) {
+					label.fromSTR(_y_labels[i].c_str()); // BUG: should interpolate into this string
+					gr_usertocm(x, _y_label_positions[i], &xcm, &ycm);
+					labelx_cm = xcm + offset * cos(angle);
+					labely_cm = ycm + offset * sin(angle) - 0.5 * CapHeight;
+
+#ifdef DEBUG_LABELS
+					printf("DEBUG: %s:%d drawing %d-th label '%s' at y=%f angle=%f\n",__FILE__,__LINE__,i,_y_labels[i].c_str(),_y_label_positions[i],angle);
+#endif
+					if (side == gr_axis_LEFT)
+						label.draw(labelx_cm, labely_cm, TEXT_RJUST, DEG_PER_RAD * angle);
+					else
+						label.draw(labelx_cm, labely_cm, TEXT_LJUST, DEG_PER_RAD * angle);
+				} else {
+#ifdef DEBUG_LABELS
+					//printf("DEBUG: %s:%d SKIPPING %d-th label '%s' since x=%f\n",__FILE__,__LINE__,i,_y_labels[i].c_str(),_y_label_positions[i]);
+#endif
+				}
+			}
+		}
 		// Finish by drawing to end of axis (in case there was no tic there).
 		axis_path.push_back(x, final, 'l');
 		axis_path.stroke(units_user, _griState.linewidth_axis());
