@@ -420,8 +420,9 @@ read_columnsCmd()
 			}
 #endif
 
-			//printf("DEBUG %s:%d.  'read columns' got [%s]\n",__FILE__,__LINE__,inLine.getValue());
-
+#if 0
+			printf("DEBUG %s:%d.  'read columns' got [%s]\n",__FILE__,__LINE__,inLine.getValue());
+#endif
 			//unsigned int this_line_len = strlen(inLine.getValue()) + 1;
 
 #ifdef REMOVE_COMMENTS_FROM_DATA
@@ -462,6 +463,7 @@ read_columnsCmd()
 						continue;
 					}
 					_colX.push_back(tmpf);
+					//printf("pushing back %lf (missing= %lf)\n",tmpf,missing);
 				}
 			}
 			if (coly > 0) {
@@ -691,6 +693,7 @@ read_columnsCmd()
 	}
 	if (_colX.size() > 0) {
 		_columns_exist = true;
+		//printf("%s:%d _xscale_exists= %d\n",__FILE__,__LINE__,_xscale_exists);
 		if (!_xscale_exists) {
 			if (!create_x_scale()) {
 				warning("Problem autoscaling -- no data or all x values equal");
@@ -1223,13 +1226,15 @@ read_grid_binary(bool bycolumns, char bintype)
 			}
 			if (items != 1) {
 				char msg[100];
-				sprintf(msg, "Can't read grid datum at col=%d, row=%d\n", col, row);
+				sprintf(msg, "Can't read grid datum at col=%d, row=%d", col, row);
 				err(msg);
 				return false;
 			}
 			_f_xy(col, row) = value;
+#if 0				// BUG: what was I doing w/ this _f_xy printing?
 			if (value < 0.0)
 				printf("_f_xy(col=%d, row=%d)=%f\n",col,row,value);
+#endif
 			_legit_xy(col, row) = gr_missing(value) ? false : true;
 		}
 		if (_chatty > 1) printf("Read row %d of grid data\n", row);
@@ -1833,7 +1838,7 @@ This is not a PGM file, since the first 2 characters\n\
 		imMask->storage_exists = false;
 	}
 	if (imMask->storage_exists) {
-		printf("%s:%d freeing imageMask storage at %x\n",__FILE__,__LINE__,(int)imMask->image);
+		printf("%s:%d freeing imageMask storage at %lx\n",__FILE__,__LINE__,(long unsigned int)imMask->image);
 		free(imMask->image);
 		imMask->storage_exists = false;
 	}
